import requests
from datetime import datetime

def scrape_lipsia():
    url = "https://wg-lipsia.de/wp-admin/admin-ajax.php?action=emk_immosearch_api&endpoint=list"
    response = requests.get(url)

    if response.status_code != 200:
        print(f"Failed to fetch data: {response.status_code}")
        return []

    data = response.json()
    if data["status"] != "success":
        print("Failed to fetch properties: Invalid response status")
        return []

    properties = []
    for item in data["list"]:

        lat = item.get("lat", "")
        lon = item.get("lon", "")
        google_maps_link = f"https://www.google.com/maps/search/?api=1&query={lat},{lon}"

        properties.append({
            "id": item.get("id"),
            "title": "Lipsia - " + item.get("headline", ""),
            "subtitle": item.get("adresse_strasse", "") + " " + item.get("adresse_plz_ort", ""),
            "rooms": item.get("zimmer_anzahl", 0),
            "size": str(item.get("wohnflaeche", 0)) + " m²",
            "rent": "Kalt: " + str(item.get("miete_kalt_euro", 0)) + " €",
            "link": google_maps_link,
            "abstract": item.get("highlight_1", ""),
            "warm_rent": "",  # Placeholder as warm rent is not provided
            "availability": (item.get("highlight_3", "")),  # Customize as needed
            "image_url": item.get("image", ""),
        })

    return properties