import requests
import xml.etree.ElementTree as ET
import src.lwb.format as format

EASYSQUARE_URL = "https://portal1s.easysquare.com/prorex/xmlforms"
EASYSQUARE_HEADERS = {
    "DNT": "1",
    "Host": "portal1s.easysquare.com",
    "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
    "Cookie": "SAP_SESSIONID_PP0_581=Vg3w4pn8whD76BldaU2wvP-YzyrRkRHvhWoKELG5Agg%3d; sap-usercontext=sap-language=D&sap-client=581; cookiesession1=678ADA67ADF0813997206FE9F4133118",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:134.0) Gecko/20100101 Firefox/134.0",
    "Accept-Encoding": "gzip, deflate, br, zstd",
    "Accept-Language": "de,en-US;q=0.7,en;q=0.3",
    "Upgrade-Insecure-Requests": "1"
}
EASYSQUARE_PARAMS = {
    "application": "ESQ_IA_REOBJ",
    "sap-client": "581",
    "command": "action",
    "name": "boxlist",
    "api": "6.169",
    "head-oppc-version": "6.169.22",
    "_": "1736761256321"
}

# curl --location 'https://portal1s.easysquare.com/prorex/xmlforms?application=ESQ_IA_REOBJ&sap-client=581&command=action&name=boxlist&api=6.169&head-oppc-version=6.169.22&_=1736761255682' \
# --header 'DNT: 1' \
# --header 'UTC: 1736761256321' \
# --header 'Host: portal1s.easysquare.com' \
# --header 'host: portal1s.easysquare.com' \
# --header 'Accept: text/plain, */*; q=0.01' \
# --header 'Cookie: cookiesession1=678ADA67ADF0813997206FE9F4133118; sap-usercontext=sap-language=de&sap-client=581; SAP_SESSIONID_PP0_581=Vg3w4pn8whD76BldaU2wvP-YzyrRkRHvhWoKELG5Agg%3d' \
# --header 'Referer: https://portal1s.easysquare.com/meinelwb/index.html?deeplink=%2FESQ_IA_REOBJ%2FESQ_VM_REOBJ_ALL' \
# --header 'Sec-GPC: 1' \
# --header 'oppc-id: D9925A2D-4ED9-4911-8AD3-2626DA41FBB0' \
# --header 'Connection: keep-alive' \
# --header 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:134.0) Gecko/20100101 Firefox/134.0' \
# --header 'Content-Type: text/plain;charset=UTF-8' \
# --header 'Sec-Fetch-Dest: empty' \
# --header 'Sec-Fetch-Mode: cors' \
# --header 'Sec-Fetch-Site: same-origin' \
# --header 'Accept-Encoding: gzip, deflate, br, zstd' \
# --header 'Accept-Language: de,en-US;q=0.7,en;q=0.3' \
# --header 'X-Requested-With: XMLHttpRequest'


# Funktion: Scrape von Easysquare
def scrape_easysquare():
    session = requests.Session()
    response = session.get(EASYSQUARE_URL, headers=EASYSQUARE_HEADERS, params=EASYSQUARE_PARAMS)
    
    if response.status_code != 200:
        print(f"Fehler beim Abrufen von Easysquare: {response.status_code}")
        return []

    # XML-Daten parsen
    root = ET.fromstring(response.content)
    namespace = {"ns": "http://www.openpromos.com/OPPC/XMLForms"}
    
    properties = []
    for head in root.findall(".//ns:head", namespace):
        prop_title = head.find("ns:title", namespace).text
        subtitle = head.find("ns:subtitle", namespace).text
        abstract = head.find("ns:abstract", namespace).text.strip()

        # get adress lat and long
        # <address city="" lat="51.346061" lon="12.3774656" postcode="" street=""/>

        adress = head.find("ns:address", namespace)
        lat = adress.get("lat")
        lon = adress.get("lon")

        image = head.find("ns:image", namespace)
        iamge_resourceId = image.get("resourceId")

        id = head.find("ns:id", namespace).text

        # Details extrahieren
        rooms = "N/A"
        size = "N/A"
        rent = "N/A"
        availability = "N/A"

        for criterion in head.findall(".//ns:criterion", namespace):
            criterion_title = criterion.get("title")
            value = criterion.text.strip() if criterion.text else "N/A"
            if criterion_title == "Zimmer":
                rooms = value
            elif criterion_title == "Fläche":
                size = value
            elif criterion_title == "Gesamtmiete":
                rent = value
            elif criterion_title == "Verfügbar ab":
                availability = value

        # link create google maps link with lat and long
        link = f"https://www.google.com/maps/search/?api=1&query={lat},{lon}"

        # https://portal1s.easysquare.com/prorex/xmlforms/image.jpg?application=ESQ_IA_REOBJ&command=action&id=1EC8D4E6-191A-A827-47FF-72D8C5379070&name=get
        image_url = f"https://portal1s.easysquare.com/prorex/xmlforms/image.jpg?application=ESQ_IA_REOBJ&command=action&id={iamge_resourceId}&name=get"

        properties.append({
            "id": id,
            "title": "LWB - " + prop_title,
            "subtitle": subtitle,
            "rooms": format.format_room(rooms),
            "size": format.format_roomSize(size),
            "rent": format.format_money(rent),
            "link": link,
            "abstract": abstract,
            "warm_rent": "",
            "availability": format.format_date(availability),
            "image_url": image_url,
        })

    return properties